pub struct Args {
pub schema_file: Option<PathBuf>,
pub project_dir: Option<PathBuf>,
pub database_url: Option<String>,
pub command: Commands,
pub hide_unknown_types: bool,
}Fields
schema_file: Option<PathBuf>Set the path to the schema definition file (defaults to the current directory)
project_dir: Option<PathBuf>Set the path to where the generated models will be saved (defaults to the path of the schema file)
database_url: Option<String>Set the DATABASE_URL which will be used in the connection
command: Commandshide_unknown_types: boolForce hiding of type that are not support by the enabled Database drivers NOTE: you will need to resolve compile errors for unsupported types.